@@ -15,6 +15,7 @@ from .circuitmap import CircuitMap  # noqa
 from .connection import CommandError  # noqa
 from .connection import Connection  # noqa
 from .const import AUTO  # noqa
+from .const import NA  # noqa
 from .const import OK  # noqa
 from .ebus import Ebus  # noqa
 from .icon import get_icon  # noqa
@@ -28,5 +29,3 @@ from .msgdef import FieldDef  # noqa
 from .msgdef import MsgDef  # noqa
 from .msgdefdecoder import decode_msgdef  # noqa
 from .msgdefs import MsgDefs  # noqa
-from .na import NA  # noqa
-from .na import NotAvailable  # noqa
