@@ -1,8 +1,11 @@
 """Common."""
+import logging
 import sys
 
 import pyebus
 
+_LOGGER = logging.getLogger(__name__).parent
+
 
 def add_msgdef_args(parser):
     """Load arguments related to :any:`load_msgdef`."""
@@ -78,4 +81,4 @@ def print_msg(msg, skipbroken=False):
                 unitvalue = ""
             print(f"{field.ident:<40s} {field.fielddef.msgdef.type_} {unitvalue!s:<20s}{details}")
     elif not skipbroken:
-        print(f"{msg.msgdef.ident:<40s}      ERROR: {msg.error}")
+        _LOGGER.error(f"{msg.msgdef.ident}: {msg.error}")
