@@ -3,10 +3,11 @@ import asyncio
 import collections
 import logging
 
-from .connection import CommandError, Connection
+from .connection import CommandError, Connection, ConnectionTimeout
 from .const import OK
 from .msg import BrokenMsg, filter_msg
 from .msgdecoder import MsgDecoder, UnknownMsgError
+from .msgdef import resolve_prio
 from .msgdefdecoder import decode_msgdef
 from .msgdefs import MsgDefs
 from .util import repr_
@@ -42,6 +43,11 @@ class Ebus:
             ),
         )
 
+    @property
+    def ident(self):
+        """Ident."""
+        return f"{self.host}:{self.port}"
+
     @property
     def host(self):
         """Host Name or IP."""
@@ -137,15 +143,6 @@ class Ebus:
         _LOGGER.info(f"read({msgdef!r}, ttl={ttl!r})")
         return await self._async_read(msgdef, ttl)
 
-    async def _async_read(self, msgdef, ttl):
-        try:
-            await self.connection.async_request("read", msgdef.name, c=msgdef.circuit, p=msgdef.setprio, m=ttl)
-            line = await self.connection.async_readresp(check=False)
-        except CommandError as exc:
-            return BrokenMsg(msgdef, str(exc))
-        else:
-            return self.msgdecoder.decode_value(msgdef, line)
-
     async def async_write(self, msgdef, value, ttl=0):
         """Write Message."""
         _LOGGER.info(f"write({msgdef!r}, value={value!r}, ttl={ttl!r})")
@@ -177,16 +174,16 @@ class Ebus:
         async for msg in self._async_listen(msgdefs):
             yield msg
 
-    async def _async_listen(self, msgdefs):
-        await self.connection.async_request("listen")
-        resp = await self.connection.async_readresp()
-        if resp != "listen started":
-            raise CommandError(f"Listen could not be started: {resp}")
-        async for line in self.connection.async_read(check=False):
-            msg = self._decode_msg(line)
-            msg = filter_msg(msg, msgdefs)
-            if msg:
-                yield msg
+    async def async_setprio(self, msgdef, setprio=None):
+        """
+        Read Message.
+
+        Raises:
+            ValueError: on decoder error
+        """
+        _LOGGER.info(f"async_setprio({msgdef!r}, setprio={setprio!r})")
+        msgdef = msgdef.replace(setprio=resolve_prio(msgdef, setprio or msgdef.setprio))
+        await self._async_read(msgdef)
 
     async def async_observe(self, msgdefs=None, ttl=None):
         """
@@ -229,6 +226,9 @@ class Ebus:
     async def async_get_state(self):
         """Return state string."""
         _LOGGER.info("get_state()")
+        return await self._async_get_state()
+
+    async def _async_get_state(self):
         try:
             await self.connection.async_request("state")
             state = await self.connection.async_readresp()
@@ -236,12 +236,13 @@ class Ebus:
                 return OK
             else:
                 return state
-        except Exception:  # pylint: disable=W0703
+        except (ConnectionError, ConnectionTimeout):
             return "no ebusd connection"
 
     async def async_is_online(self):
         """Return if we are online."""
-        state = await self.async_get_state()
+        _LOGGER.info("is_online()")
+        state = await self._async_get_state()
         return state == OK
 
     async def async_get_info(self):
@@ -261,6 +262,26 @@ class Ebus:
         async for line in self.connection.async_read(infinite=infinite, check=check):
             yield line
 
+    async def _async_read(self, msgdef, ttl=None):
+        try:
+            await self.connection.async_request("read", msgdef.name, c=msgdef.circuit, p=msgdef.setprio, m=ttl)
+            line = await self.connection.async_readresp(check=False)
+        except CommandError as exc:
+            return BrokenMsg(msgdef, str(exc))
+        else:
+            return self.msgdecoder.decode_value(msgdef, line)
+
+    async def _async_listen(self, msgdefs):
+        await self.connection.async_request("listen")
+        resp = await self.connection.async_readresp()
+        if resp != "listen started":
+            raise CommandError(f"Listen could not be started: {resp}")
+        async for line in self.connection.async_read(check=False):
+            msg = self._decode_msg(line)
+            msg = filter_msg(msg, msgdefs)
+            if msg:
+                yield msg
+
     def _decode_msg(self, line):
         if line:
             try:
