@@ -1,8 +1,8 @@
 """EBUS Message Decoding."""
 import re
 
+from .const import NA
 from .msg import BrokenMsg, Field, Msg
-from .na import NA
 
 
 class MsgDecoder:
