@@ -4,6 +4,7 @@ import copy
 
 from anytree import NodeMixin
 
+from .const import AUTO
 from .util import repr_
 
 _MsgDef = collections.namedtuple("_MsgDef", "circuit name read prio write update setprio")
@@ -216,3 +217,18 @@ class VirtFieldDef(AbstractFieldDef):
 
     def __repr__(self):
         return repr_(self, (self.name, self.type_))
+
+
+def resolve_prio(msgdef, setprio):
+    """Calculate best priority."""
+    if msgdef.read:
+        if setprio == AUTO:
+            # Prio is only available on read messages.
+            if msgdef.update or msgdef.write:
+                # we just want to ensure that we do not miss any value
+                setprio = 2
+            else:
+                setprio = 1
+        return setprio
+    else:
+        return None
