@@ -4,7 +4,7 @@ import re
 from fnmatch import fnmatch
 
 from .const import AUTO
-from .util import resolve_prio
+from .msgdef import resolve_prio
 
 
 class MsgDefs:
