@@ -5,8 +5,8 @@ Fields which are assembled/calcuated from one or more other fields.
 """
 import datetime
 
+from .const import NA
 from .msgdef import VirtFieldDef
-from .na import NA
 from .types import DateTimeType, DateType, HourMinuteType, TimeType
 
 
@@ -57,7 +57,7 @@ def iter_virtfielddefs(fielddefs):
 
 def _merge_date_time(date, time, state=None):
     if date not in (None, NA) and time not in (None, NA):
-        if state in (None, "valid"):
+        if state in (None, "valid", "ok"):
             if date and time:
                 return datetime.datetime(date.year, date.month, date.day, time.hour, time.minute, time.second)
             else:
